TenjinSDK class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
appendAppSubversion (int value )
→ void
connect ()
→ void
eventAdImpressionAdMob (Map <String , dynamic > json )
→ void
eventAdImpressionAppLovin (Map <String , dynamic > json )
→ void
eventAdImpressionHyperBid (Map <String , dynamic > json )
→ void
eventAdImpressionIronSource (Map <String , dynamic > json )
→ void
eventAdImpressionTopOn (Map <String , dynamic > json )
→ void
eventAdImpressionTradPlus (Map <String , dynamic > json )
→ void
eventAdImpressionTradPlusAdInfo (Map <String , dynamic > json )
→ void
eventWithName (String name )
→ void
eventWithNameAndValue (String name , int value )
→ void
getAnalyticsInstallationId ()
→ Future <String ? >
getAttributionInfo ()
→ Future <Map <String , dynamic > ? >
getCustomerUserId ()
→ Future <String ? >
getUserProfileDictionary ()
→ Future <Map <String , dynamic > ? >
init ({required String apiKey })
→ void
initialize ({required String sdkKey })
→ void
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optIn ()
→ void
optInGoogleDMA ()
→ void
optInOutUsingCMP ()
→ void
optInParams (List <String > params )
→ void
optOut ()
→ void
optOutGoogleDMA ()
→ void
optOutParams (List <String > params )
→ void
registerAppForAdNetworkAttribution ()
→ void
requestTrackingAuthorization ()
→ Future <bool >
resetUserProfile ()
→ void
setCacheEventSetting (bool setting )
→ void
setCustomerUserId (String userId )
→ void
setEncryptRequestsSetting (bool setting )
→ void
setGoogleDMAParameters (bool adPersonalization , bool adUserData )
→ void
subscription ({required String productId , required String currencyCode , required double unitPrice , String ? iosTransactionId , String ? iosOriginalTransactionId , String ? iosReceipt , String ? iosSKTransaction , String ? androidPurchaseToken , String ? androidPurchaseData , String ? androidDataSignature })
→ void
Track a subscription with full transaction data (iOS only for now).
subscriptionWithStoreKit ({required String productId , required String currencyCode , required double unitPrice })
→ Future <void >
Track a subscription by fetching SK2 transaction data natively (iOS only).
Recommended for RevenueCat and other IAP libraries that don't expose SK2 data.
toString ()
→ String
A string representation of this object.
inherited
transaction (String productName , String currencyCode , double quantity , double unitPrice )
→ void
transactionWithReceipt ({required String productId , required String currencyCode , required double unitPrice , required int quantity , String ? androidPurchaseData , String ? androidDataSignature , String ? iosReceipt , String ? iosTransactionId })
→ void
updatePostbackConversionValue (int conversionValue )
→ void
updatePostbackConversionValueCoarseValue (int conversionValue , String coarseValue )
→ void
updatePostbackConversionValueCoarseValueLockWindow (int conversionValue , String coarseValue , bool lockWindow )
→ void